==> refcomp-services-1.4-bin.zip: fr/inra/refcomp/services/RefcompServiceMain.java <==
/*
 * #%L
 * Refcomp :: services
 * 
 * $Id: RefcompServiceMain.java 173 2011-05-27 08:32:56Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.4/refcomp-services/src/main/java/fr/inra/refcomp/services/RefcompServiceMain.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.services;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.i18n.I18n;

/**
 * User: couteau
 * Date: 01/02/11
 */
public class RefcompServiceMain {

    /**
     * log.
     */
    private static final Log log = LogFactory.getLog(RefcompServiceMain.class);

    public static void main(String[] args) {

        // Initialise config
        RefcompConfiguration config = RefcompConfiguration.getInstance(args);

        try {
            // Launch actions
            config.doAction(RefcompConfiguration.STEP_AFTER_INIT);
        } catch (Exception eee) {
            if (log.isErrorEnabled()) {
                log.error("Can't run actions ", eee);
            }
        }
    }
}

==> refcomp-services-1.6-bin.zip: fr/inra/refcomp/services/RefcompServiceMain.java <==
/*
 * #%L
 * Refcomp :: services
 * 
 * $Id: RefcompServiceMain.java 252 2012-01-31 15:04:12Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.6/refcomp-services/src/main/java/fr/inra/refcomp/services/RefcompServiceMain.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.services;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * User: couteau
 * Date: 01/02/11
 */
public class RefcompServiceMain {

    /**
     * log.
     */
    private static final Log log = LogFactory.getLog(RefcompServiceMain.class);

    public static void main(String[] args) {

        // Initialise config
        RefcompConfiguration config = new RefcompConfiguration();

        try {
            // Launch actions
            config.applicationConfig.doAction(0);
        } catch (Exception eee) {
            if (log.isErrorEnabled()) {
                log.error("Can't run actions ", eee);
            }
        }
    }
}
